#ifndef P_CHECKER_PATTERN
#define P_CHECKER_PATTERN

#include "PixelCallback.h"

typedef struct Checker {
	u32 squareSize;
	color colorA;
	color colorB;
} Checker;

PixelCallback* Checker_setup(Checker obj);

#endif /* P_CHECKER_PATTERN */
