#ifndef _PIXEL_CALLBACK
#define _PIXEL_CALLBACK

#include "../global.h"
#include "../RGBImage.h"

struct PixelContext {
	i32 x;
	i32 y;
	ARGB pixel;
};

typedef void (*PixelCallback_callback)(void* self, struct PixelContext* pc);

typedef struct PixelCallback {
	PixelCallback_callback callback;
	void* callback_self;
} PixelCallback;

#endif /* _PIXEL_CALLBACK */
