#ifndef P_SQUARE
#define P_SQUARE

#include "PixelCallback.h"

typedef struct Square {
	u32 width;
	u32 height;
	color color;
} Square;

PixelCallback* Square_setup(Square obj);

#endif /* P_SQUARE */
