#include "P_Image.h"
#include "PixelCallback.h"
#include <stdlib.h>
#include <string.h>

void Image_callback(Image* self, struct PixelContext* fc) {
	if (0 <= fc->x && fc->x < self->img.width * self->scale &&
	    0 <= fc->y && fc->y < self->img.height * self->scale)
	{
		ARGB_mergeARGB(&fc->pixel, *RGBImage_at(self->img, fc->y / self->scale, fc->x / self->scale));
	}
}

PixelCallback* Image_setup(Image obj) {
	PixelCallback* pca = malloc(sizeof(struct PixelCallback));

	pca->callback = (PixelCallback_callback)Image_callback;
	pca->callback_self = malloc(sizeof(obj));
	memcpy(pca->callback_self, &obj, sizeof(obj));

	return pca;
}
